@@ -25,6 +25,7 @@ import (
 	"context"
 	"encoding/gob"
 	"fmt"
+	"maps"
 	"os"
 	"path/filepath"
 	"strings"
@@ -46,6 +47,7 @@ func init() {
 	MachoCmd.AddCommand(machoDisassCmd)
 	// machoDisassCmd.Flags().Uint64("slide", 0, "MachO slide to remove from --vaddr")
 	machoDisassCmd.Flags().String("arch", "", "Which architecture to use for fat/universal MachO")
+	machoDisassCmd.Flags().BoolP("entry", "e", false, "Disassemble entry point")
 	machoDisassCmd.Flags().StringP("symbol", "s", "", "Function to disassemble")
 	machoDisassCmd.Flags().Uint64P("vaddr", "a", 0, "Virtual address to start disassembling")
 	machoDisassCmd.Flags().Uint64P("off", "o", 0, "File offset to start disassembling")
@@ -60,8 +62,10 @@ func init() {
 	machoDisassCmd.Flags().StringP("section", "x", "", "Disassemble an entire segment/section (i.e. __TEXT_EXEC.__text)")
 	machoDisassCmd.Flags().String("cache", "", "Path to .a2s addr to sym cache file (speeds up analysis)")
 	machoDisassCmd.Flags().Bool("replace", false, "Replace .a2s")
+	machoDisassCmd.MarkFlagsMutuallyExclusive("entry", "symbol", "vaddr", "off")
 
 	viper.BindPFlag("macho.disass.arch", machoDisassCmd.Flags().Lookup("arch"))
+	viper.BindPFlag("macho.disass.entry", machoDisassCmd.Flags().Lookup("entry"))
 	viper.BindPFlag("macho.disass.symbol", machoDisassCmd.Flags().Lookup("symbol"))
 	viper.BindPFlag("macho.disass.vaddr", machoDisassCmd.Flags().Lookup("vaddr"))
 	viper.BindPFlag("macho.disass.off", machoDisassCmd.Flags().Lookup("off"))
@@ -92,7 +96,6 @@ var machoDisassCmd = &cobra.Command{
 		var m *macho.File
 		var ms []*macho.File
 		var middleAddr uint64
-		var symbolMap map[uint64]string
 		var engine *disass.MachoDisass
 
 		if viper.GetBool("verbose") {
@@ -102,6 +105,7 @@ var machoDisassCmd = &cobra.Command{
 
 		// flags
 		selectedArch := viper.GetString("macho.info.arch")
+		entryStart := viper.GetBool("macho.disass.entry")
 		symbolName := viper.GetString("macho.disass.symbol")
 		startAddr := viper.GetUint64("macho.disass.vaddr")
 		startOff := viper.GetUint64("macho.disass.off")
@@ -119,13 +123,9 @@ var machoDisassCmd = &cobra.Command{
 		allFuncs := false
 
 		// validate args
-		if len(symbolName) > 0 && (startAddr != 0 || startOff != 0) {
-			return fmt.Errorf("you can only use --symbol OR --vaddr/--off (not both)")
-		} else if len(symbolName) == 0 && startAddr == 0 && startOff == 0 {
+		if len(symbolName) == 0 && startAddr == 0 && startOff == 0 && !entryStart {
 			allFuncs = true
 			// return fmt.Errorf("you must supply a --symbol OR --vaddr to disassemble")
-		} else if startAddr != 0 && startOff != 0 {
-			return fmt.Errorf("you can only use --vaddr OR --off (not both)")
 		}
 		if len(filesetEntry) > 0 && viper.GetBool("macho.disass.all-fileset-entries") {
 			return fmt.Errorf("you can only use --fileset-entry OR --all-fileset-entries (not both)")
@@ -139,6 +139,10 @@ var machoDisassCmd = &cobra.Command{
 			return fmt.Errorf("failed to detect file type: %v", err)
 		}
 
+		// symbol caches
+		symbolMap := make(map[uint64]string)
+		dSymMap := make(map[uint64]string)
+
 		fat, err := macho.OpenFat(machoPath)
 		if err != nil && err != macho.ErrNotFat {
 			log.Fatal(err.Error())
@@ -215,10 +219,15 @@ var machoDisassCmd = &cobra.Command{
 			ms = append(ms, m)
 		}
 
-		symbolMap = make(map[uint64]string)
-
 		if err := ctrlc.Default.Run(context.Background(), func() error {
 			for _, m := range ms {
+				if entryStart {
+					if main := m.GetLoadsByName("LC_MAIN"); len(main) == 0 {
+						return fmt.Errorf("failed to find LC_MAIN in target when using --entry flag")
+					} else {
+						startAddr = main[0].(*macho.EntryPoint).EntryOffset + m.GetBaseAddress()
+					}
+				}
 				if startAddr == 0 && startOff != 0 {
 					if startAddr, err = m.GetVMAddress(startOff); err != nil {
 						return fmt.Errorf("failed to get vmaddr for file offset %#x: %v", startOff, err)
@@ -233,6 +242,27 @@ var machoDisassCmd = &cobra.Command{
 						if _, err := os.Create(cacheFile); err != nil {
 							return fmt.Errorf("failed to create address-to-symbol cache file %s: %v", cacheFile, err)
 						}
+						// if dSYM file exists, load symbols from it
+						dsym := filepath.Join(machoPath+".dSYM", "Contents/Resources/DWARF", filepath.Base(machoPath))
+						if _, err := os.Stat(dsym); err == nil {
+							log.Info("Detected dSYM file, using it for symbolication")
+							dm, err := macho.Open(dsym)
+							if err != nil {
+								log.Errorf("failed to open dSYM file for symbolication: %v", err)
+							} else {
+								for _, sym := range dm.Symtab.Syms {
+									if sym.Name != "" {
+										dSymMap[sym.Value] = sym.Name
+									}
+								}
+								// If the dSYM file has a symbol map, use it for the output
+								if len(dSymMap) > 0 {
+									log.Infof("Using dSYM symbol map with %d symbols", len(dSymMap))
+								} else {
+									log.Warn("No symbols found in dSYM file")
+								}
+							}
+						}
 					} else {
 						log.Infof("Loading symbol cache file...")
 						if f, err := os.Open(cacheFile); err != nil {
@@ -299,6 +329,7 @@ var machoDisassCmd = &cobra.Command{
 									}
 								}
 							}
+							maps.Copy(symbolMap, dSymMap) // merge dSYM symbols into symbolMap
 							if err := engine.SaveAddrToSymMap(cacheFile); err != nil {
 								log.Errorf("failed to save symbol map: %v", err)
 							}
@@ -392,11 +423,14 @@ var machoDisassCmd = &cobra.Command{
 						if err := engine.Triage(); err != nil {
 							return fmt.Errorf("first pass triage failed: %v", err)
 						}
-						if err := engine.Analyze(); err != nil {
-							if !viper.GetBool("macho.disass.force") {
-								return fmt.Errorf("MachO analysis failed: %v (use --force to continue anyway)", err)
+						if len(symbolMap) == 0 {
+							if err := engine.Analyze(); err != nil {
+								if !viper.GetBool("macho.disass.force") {
+									return fmt.Errorf("MachO analysis failed: %v (use --force to continue anyway)", err)
+								}
 							}
 						}
+						maps.Copy(symbolMap, dSymMap) // merge dSYM symbols into symbolMap
 						if err := engine.SaveAddrToSymMap(cacheFile); err != nil {
 							log.Errorf("failed to save symbol map: %v", err)
 						}
